import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import * as React from "react";
import { Text } from "./Text";
import { CloseButton } from "./IconButton";
import { useTransition, animated } from "react-spring";
import { Overlay } from "./Overlay";
import { useFocusElement } from "./Hooks/use-focus-trap";
import PropTypes from "prop-types";
//import {useScrollLock} from "./Hooks/use-scroll-lock";
import { useTheme } from "./Theme/Providers";
/**
 * A dialog is useful for displaying infomation that
 * commands the user's attention.
 */
export const Dialog = ({ isOpen, onRequestClose, mobileFullscreen, title, children, ...other }) => {
    const theme = useTheme();
    // [TransitionFn<Item, State & object>, SpringStartFn<State>, SpringStopFn<State>]
    const transitions = useTransition(isOpen, {
        from: { opacity: 0, transform: "scale(0.9)" },
        enter: { opacity: 1, transform: "scale(1)" },
        leave: { opacity: 0, transform: "scale(0.9)" },
        config: { mass: 1, tension: 185, friction: 26 }
    });
    //const scrollableRef = React.useRef(null);
    const ref = React.useRef(null);
    useFocusElement(ref, isOpen);
    //use-scroll-lock仅仅这里用1回，？毛病，手机上为啥不能滚动，电脑可以滚动。
    //useScrollLock(isOpen, scrollableRef); 还是删掉更好点 <div ref={scrollableRef}>{children}</div>
    return (_jsx(React.Fragment, { children: _jsx(Overlay, { onRequestClose: onRequestClose, isOpen: isOpen, style: {
                //display: "block",   //display: 'flex',
                alignItems: mobileFullscreen ? undefined : 'center',
                [theme.mediaQueries.md]: {
                    alignItems: 'center'
                },
                [theme.mediaQueries.lg]: {
                    alignItems: 'center'
                }
            }, children: _jsx(React.Fragment, { children: transitions((style, item) => {
                    return (item && _jsx(animated.div, { className: "DialogTop", "aria-modal": "true", ref: ref, tabIndex: -1, onClick: (e) => {
                            e.stopPropagation();
                        }, style: {
                            opacity: style.opacity,
                            transform: style.transform,
                            //display: "block",为什么老有缓存: 必须整个拷贝esm/? package.json版本没变 +@须用调试运行模式。
                        }, css: [
                            {
                                //display: "block",
                                zIndex: theme.zIndices.modal,
                                background: theme.colors.background.default,
                                boxShadow: theme.shadows.md,
                                borderRadius: theme.radii.lg,
                                margin: "16px",
                                width: "calc(100% - 32px)",
                                outline: "none",
                                overflow: 'visible',
                                [theme.mediaQueries.md]: {
                                    maxWidth: "700px",
                                    margin: "30px auto",
                                    // maxHeight: `calc(100vh - 2 * 30px)`
                                },
                                [theme.mediaQueries.lg]: {
                                    maxWidth: "980px",
                                    margin: "30px auto",
                                    // maxHeight: `calc(100vh - 2 * 30px)`
                                }
                            },
                            mobileFullscreen && {
                                //display: "block",
                                maxWidth: "none",
                                margin: 0,
                                width: "100%",
                                //height: "100vh",
                                //minHeight: "100vh",
                                borderRadius: 0,
                                boxShadow: "none",
                                [theme.mediaQueries.md]: {
                                    maxWidth: "700px",
                                    // height: "auto",
                                    minHeight: "40vh",
                                    boxShadow: theme.shadows.md,
                                    width: "calc(100% - 32px)",
                                    borderRadius: theme.radii.lg,
                                    margin: "30px auto",
                                    // maxHeight: `calc(100vh - 2 * 30px)`
                                },
                                [theme.mediaQueries.lg]: {
                                    maxWidth: "980px",
                                    margin: "30px auto",
                                    // maxHeight: `calc(100vh - 2 * 30px)`
                                }
                            }
                        ], ...other, children: _jsxs(React.Fragment, { children: [title && (_jsx(DialogHeader, { className: "Dialog__header", css: {
                                        display: "flex",
                                        justifyContent: "space-between",
                                        alignItems: "center",
                                        padding: `${theme.spaces.lg} ${theme.spaces.lg} 0 ${theme.spaces.lg}`
                                    }, title: title, onRequestClose: onRequestClose })), _jsx("div", { children: children })] }) }, 1));
                }) }) }) }));
};
Dialog.propTypes = {
    isOpen: PropTypes.bool.isRequired,
    onRequestClose: PropTypes.func.isRequired,
    title: PropTypes.string,
    mobileFullscreen: PropTypes.bool,
    children: PropTypes.node
};
export const DialogHeader = ({ title, onRequestClose, ...other }) => (_jsxs("div", { ...other, children: [_jsx(Text, { wrap: false, variant: "h4", children: title }), onRequestClose && _jsx(CloseButton, { onClick: onRequestClose })] }));
DialogHeader.propTypes = {
    title: PropTypes.string.isRequired,
    onRequestClose: PropTypes.func
};
//# sourceMappingURL=Dialog.js.map