import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import { Text } from "./Text";
import PropTypes from "prop-types";
import { MenuLabel } from "./Menu";
import { useTheme } from "./Theme/Providers";
import { noOp } from "./misc/noop";
import { useTouchable } from "./Hooks/touchable-hook";
import { safeBind } from "./Hooks/compose-bind";
export const List = ({ children, ...other }) => {
    return _jsx("nav", { ...other, children: children });
};
List.propTypes = {
    children: PropTypes.node
};
/**列表底下的各个项目：可以插入大类分类层次 ListSection。
 *    <ListSection >
         <ListItem  />
      </ListSection>
      <Divider muted />
 * */
export const ListItem = ({ primary, secondary, contentBefore, interactive = true, children, wrap = true, contentAfter, onPress = noOp, component: Component = "div", noBind = false, terminateOnScroll = false, delay = 30, secondStyle, ...other }) => {
    const interactiveProps = interactive
        ? {
            role: "button",
            tabIndex: 0
        }
        : {};
    const isLink = other.to || other.href;
    //这个{bind｛ref｝}给了哪一个Div;那么就针对哪一个DIV的矩形框框才能触发函数 onPress()。从z-index维度上看上一层的更小的div优先。
    const { bind, hover, active } = useTouchable({
        onPress,
        delay,
        terminateOnScroll,
        behavior: isLink ? "link" : "button"
    });
    const theme = useTheme();
    //console.log("ListItemdl=",delay, "terminateOnScroll=",terminateOnScroll);
    return (_jsx(Component, { className: "ListItem", css: [
            {
                display: "block",
                textDecoration: "none",
                outline: "none",
                padding: theme.spaces.sm,
                background: "transparent",
                WebkitTapHighlightColor: "transparent",
                transition: "background 0.07s ease",
                [theme.mediaQueries.lg]: {
                    paddingLeft: theme.spaces.lg,
                    paddingRight: theme.spaces.lg
                },
                ":last-child": {
                    borderBottom: "none"
                }
            },
            interactive && {
                cursor: "pointer",
                ":focus": {
                    boxShadow: `inset 0 0 3px ${theme.colors.text.selected}`
                },
                ":focus:not([data-focus-visible-added])": {
                    boxShadow: "none"
                }
            },
            interactive &&
                hover && {
                background: theme.colors.background.tint1
            },
            interactive &&
                active && {
                background: theme.colors.background.tint2
            }
        ], ...interactiveProps, ...safeBind(!noBind && interactive ? bind : {}, other), children: _jsxs("div", { className: "ListItem__container", css: { display: "flex", alignItems: "center" }, children: [contentBefore && (_jsx("div", { className: "ListItem__content-before", css: { marginRight: theme.spaces.md }, children: contentBefore })), _jsxs("div", { className: "ListItem__content", css: { flex: 1, overflow: "hidden" }, children: [_jsx(Text, { className: "ListItem__primary", wrap: wrap, variant: "body", css: { display: "block", fontWeight: 500 }, children: primary }), secondary && (_jsx(Text, { className: "ListItem__secondary", wrap: wrap, css: [
                                {
                                    display: "block",
                                    fontSize: theme.fontSizes[0],
                                },
                                secondStyle
                            ], variant: "body", muted: true, children: secondary })), children] }), contentAfter && (_jsx("div", { className: "ListItem__content-after", css: { flex: "0 0 auto" }, children: contentAfter }))] }) }));
};
ListItem.propTypes = {
    primary: PropTypes.oneOfType([PropTypes.string, PropTypes.node]).isRequired,
    secondary: PropTypes.oneOfType([PropTypes.string, PropTypes.node]),
    contentBefore: PropTypes.node,
    contentAfter: PropTypes.node,
    wrap: PropTypes.bool,
    children: PropTypes.node,
    interactive: PropTypes.bool,
    terminateOnScroll: PropTypes.bool,
    noBind: PropTypes.bool,
    onPress: PropTypes.func
};
export const ListSection = ({ title, children, sticky = true, ...other }) => {
    const theme = useTheme();
    const bg = theme.colors.background.layer;
    return (_jsxs("div", { css: {
            ":first-child > *": {
                borderTop: "none"
            }
        }, children: [_jsx(MenuLabel, { css: {
                    position: sticky ? "sticky" : "static",
                    top: 0,
                    backgroundColor: sticky ? bg : "transparent",
                    padding: theme.spaces.sm,
                    paddingLeft: theme.spaces.md,
                    marginTop: theme.spaces.md,
                    [theme.mediaQueries.lg]: {
                        paddingLeft: theme.spaces.lg,
                        paddingRight: theme.spaces.lg
                    }
                }, ...other, children: title }), children] }));
};
ListSection.propTypes = {
    title: PropTypes.string.isRequired,
    sticky: PropTypes.bool,
    children: PropTypes.node
};
//# sourceMappingURL=List.js.map